==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QMdiArea_shell.h <==
#ifndef QMDIAREA_SHELL_H
#define QMDIAREA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(mdiarea)
#include <QtWidgets/qmdiarea.h>
#endif //QT_CONFIG(mdiarea)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(mdiarea)
#include <QtWidgets/qmdisubwindow.h>
#endif //QT_CONFIG(mdiarea)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#if QT_CONFIG(tabwidget)
#include <QtWidgets/qtabwidget.h>
#endif //QT_CONFIG(tabwidget)
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(mdiarea)

class QMdiArea_shell : public QMdiArea, public QtJambiShellInterface
{
public:
    QMdiArea_shell(QWidget* parent0 = nullptr);
    ~QMdiArea_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* childEvent0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* paintEvent0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* resizeEvent0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* showEvent0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* timerEvent0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMdiArea_access : public QMdiArea
{
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childEvent0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, QtJambiNativeID event1);
    jobject __qt_minimumSizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID paintEvent0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID resizeEvent0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_setupViewport_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID viewport0);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID showEvent0);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID timerEvent0);
    jboolean __qt_viewportEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QT_CONFIG(mdiarea)
#endif // QMDIAREA_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QMdiArea_shell.h <==
#ifndef QMDIAREA_SHELL_H
#define QMDIAREA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(mdiarea)
#include <QtWidgets/qmdiarea.h>
#endif //QT_CONFIG(mdiarea)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(mdiarea)
#include <QtWidgets/qmdisubwindow.h>
#endif //QT_CONFIG(mdiarea)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#if QT_CONFIG(tabwidget)
#include <QtWidgets/qtabwidget.h>
#endif //QT_CONFIG(tabwidget)
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(mdiarea)

class QMdiArea_shell : public QMdiArea, public QtJambiShellInterface
{
public:
    QMdiArea_shell(QWidget* parent0 = nullptr);
    ~QMdiArea_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QMdiArea_mshell;
    friend class QMdiArea_oshell;
};


class QMdiArea_mshell : public QMdiArea_shell
{
public:
    using QMdiArea_shell::QMdiArea_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QMdiArea_oshell : public QMdiArea_mshell
{
public:
    using QMdiArea_mshell::QMdiArea_mshell;
    ~QMdiArea_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* childEvent0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* object0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* paintEvent0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* resizeEvent0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* showEvent0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* timerEvent0) override;
    bool viewportEvent(QEvent* event0) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMdiArea_access : public QMdiArea
{
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID childEvent0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, QtJambiNativeID event1);
    jobject __qt_minimumSizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID paintEvent0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID resizeEvent0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_setupViewport_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID viewport0);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID showEvent0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID timerEvent0);
    jboolean __qt_viewportEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QT_CONFIG(mdiarea)
#endif // QMDIAREA_SHELL_H
